package com.blackberry.workspaces.api.sdk.examples;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import com.blackberry.workspaces.api.sdk.APISession;
import com.blackberry.workspaces.api.sdk.json.BulkOperationResultJson;
import com.blackberry.workspaces.api.sdk.json.CopyMembershipJson;
import com.blackberry.workspaces.api.sdk.json.EditUserJson;
import com.blackberry.workspaces.api.sdk.json.RemoveUsersJson;
import com.blackberry.workspaces.api.sdk.json.UserDetailsJson;
import com.blackberry.workspaces.api.sdk.json.UserJson;
import com.blackberry.workspaces.api.sdk.json.UsersJson;
import com.blackberry.workspaces.api.sdk.resource.Users;
import com.blackberry.workspaces.api.sdk.resource.Organizations;

/**
 * Examples of Workspaces User functionality
 * 
 * @author tasfaw
 *
 */
public class UsersExample
{
    private APISession apiSession;

    /**
     * Creates an instances of the UsersExample class
     * @param apiSession An ApiSession instance to be used.
     */
    public UsersExample(APISession apiSession)
    {
        this.apiSession = apiSession;
    }

    /*
     * Example to add a specific user.
     */
    public BulkOperationResultJson addUser(String userEmail, Set<String> aliases, Set<String> roles,
                                           String friendlyName)
    {
        Organizations organizations = apiSession.getOrganizationsResource();

        UsersJson usersJson = new UsersJson();
        UserJson userJson = new UserJson();
        UserDetailsJson UserDetailsJson = new UserDetailsJson();
        List<UserJson> userJsonList = new ArrayList<UserJson>();

        UserDetailsJson.setAliases(aliases);
        UserDetailsJson.setRoles(roles);
        UserDetailsJson.setUserName(friendlyName);
        userJson.setUserEmail(userEmail);
        userJson.setUserDetails(UserDetailsJson);
        userJsonList.add(userJson);
        usersJson.setUsers(userJsonList);

        return organizations.addUsersV30(usersJson);
    }

    /*
     * Example to edit a specific user.
     */
    public BulkOperationResultJson editUser(String language, boolean sendNotifications, boolean updateSendNotifications,
                                            int timezoneOffset, boolean updateTimezoneOffset, String userName,
                                            boolean updateUserName)
    {
        Users users = apiSession.getUsersResource();
        EditUserJson editUserJson = new EditUserJson();

        editUserJson.setLanguage(language);
        editUserJson.setSendNotifications(sendNotifications);
        editUserJson.setUpdateSendNotifications(updateSendNotifications);
        editUserJson.setTimezoneOffset(timezoneOffset);
        editUserJson.setUpdateTimezoneOffset(updateTimezoneOffset);
        editUserJson.setUserName(userName);
        editUserJson.setUpdateUserName(updateUserName);

        return users.editUserV30(editUserJson);
    }

    /*
     * Example to remove users.
     */
    public BulkOperationResultJson removeUsers(List<String> users)
    {
        Organizations organizations = apiSession.getOrganizationsResource();
        RemoveUsersJson removeUsersJson = new RemoveUsersJson();

        removeUsersJson.setForceAction(Boolean.TRUE);
        removeUsersJson.setUsers(users);

        return organizations.deleteUsersV30(removeUsersJson);
    }

    /*
     * Example to copy membership( of several users ) to another existing user.
     */
    public BulkOperationResultJson copyMemebership(List<String> usersFrom, String userTo)
    {
        Organizations organizations = apiSession.getOrganizationsResource();
        CopyMembershipJson copyMembershipJson = new CopyMembershipJson();

        copyMembershipJson.setForceAction(Boolean.TRUE);
        copyMembershipJson.setUsersFrom(usersFrom);
        copyMembershipJson.setUserTo(userTo);

        return organizations.copyMembershipV30(copyMembershipJson);
    }

}
